@@ -1,9 +1,9 @@
 ;; -*- no-byte-compile: t; lexical-binding: nil -*-
-(define-package "ruby-electric" "2.3.3"
+(define-package "ruby-electric" "20250110.1017"
   "Minor mode for electrically editing ruby code."
   ()
   :url "https://github.com/ruby/elisp-ruby-electric"
-  :commit "f2323cd9b5df3b34aa9810ba8109502824925d23"
-  :revdesc "f2323cd9b5df"
+  :commit "c53376da891713e0c49f01aad2ff64d4fbb0b812"
+  :revdesc "c53376da8917"
   :keywords '("languages" "ruby")
   :maintainers '(("Akinori MUSHA" . "knu@iDaemons.org")))
